## ----Options, echo = FALSE, message = FALSE-----------------------------------
knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
options(tibble.print_min = 4L, tibble.print_max = 4L)

## ----eval = FALSE-------------------------------------------------------------
#  remotes::install_github("CuvierLab/HicAggR")

## ----eval = TRUE, message = FALSE---------------------------------------------
library(HicAggR)

## ----eval = TRUE, message = FALSE---------------------------------------------
options(timeout = 3600) 
temp.dir <- file.path(tempdir(), "HIC_DATA")
dir.create(temp.dir)

Hic.url <- paste0("https://4dn-open-data-public.s3.amazonaws.com/",
"fourfront-webprod/wfoutput/7386f953-8da9-47b0-acb2-931cba810544/",
"4DNFIOTPSS3L.hic")
HicOutput.pth <- file.path(temp.dir, "Control_HIC.hic")
HicOutput.pth <- normalizePath(HicOutput.pth)
if(.Platform$OS.type == "windows"){
    download.file(Hic.url, HicOutput.pth, method = 'auto',
        extra = '-k',mode="wb")
}else{
    download.file(Hic.url, HicOutput.pth, method = 'auto', extra = '-k')
}


## ----eval = TRUE--------------------------------------------------------------
data("Beaf32_Peaks.gnr")

## ----echo = FALSE, eval = TRUE, message = FALSE-------------------------------
Beaf_Peaks.dtf <- Beaf32_Peaks.gnr |> as.data.frame() |> head(n=3L)
Beaf_Peaks.dtf <- Beaf_Peaks.dtf[,-c(4)]
knitr::kable(Beaf_Peaks.dtf[,c(1:4,6,5)],
    col.names = c(
        "seq","start","end","strand",
        "name","score"),
    align  = "rccccc",
    digits = 1
)

## ----eval = TRUE--------------------------------------------------------------
seqlengths.num <- c('2L'=23513712, '2R'=25286936)
chromSizes  <- data.frame(
    seqnames   = names(seqlengths.num ), 
    seqlengths = seqlengths.num
    )
binSize <- 1000

## ----eval = TRUE, results = FALSE---------------------------------------------
hicLst <- ImportHiC(
    file      = HicOutput.pth,
    hicResolution       = binSize,
    chrom_1   = c("2L", "2R")
    )

## ----eval = TRUE, results = FALSE---------------------------------------------
hicLst <- BalanceHiC(hicLst)

## ----eval = TRUE, results = FALSE---------------------------------------------
hicLst <- OverExpectedHiC(hicLst)

## ----eval = TRUE, results = FALSE---------------------------------------------
Beaf_Index.gnr <- IndexFeatures(
    gRangeList        = list(Beaf = Beaf32_Peaks.gnr),
    chromSizes         = chromSizes,
    binSize           = binSize
    )

## ----eval = TRUE, results = FALSE---------------------------------------------
Beaf_Pairs.gni <- SearchPairs(
    indexAnchor = Beaf_Index.gnr,
    minDist     = "25KB",
    maxDist     = "100KB"
    )

## ----eval = TRUE, echo = FALSE------------------------------------------------
knitr::include_graphics("images/Extractions_of_LRI.png")

## ----eval = TRUE, results = FALSE---------------------------------------------
Beaf.mtx_lst <- ExtractSubmatrix(
    genomicFeature  = Beaf_Pairs.gni,
    hicLst = hicLst
    )

## ----eval = TRUE, message = FALSE---------------------------------------------
Beaf.mtx_lst <- PrepareMtxList(
    matrices = Beaf.mtx_lst
)

## ----eval = TRUE, message = FALSE---------------------------------------------
aggreg.mtx <- Aggregation(Beaf.mtx_lst)

## ----eval = TRUE, fig.dim = c(7,7), warning=FALSE-----------------------------
ggAPA(
    aggregatedMtx = aggreg.mtx,
    title = "APA Beaf <-> Beaf"
    )

## ----eval = TRUE--------------------------------------------------------------
sessionInfo()

